commit 0573bf92e08715266d97ba8cec74107d084744c8
Author: Enrico Forestieri <[email protected]>
Date:   Sat Sep 28 16:08:06 2019 +0200

    Fix bug 11667
    
    When automatic command termination was added to texstream it was
    forgotten to reset its status after a math inset.
---
 src/mathed/InsetMathNest.cpp |    3 ++-
 1 files changed, 2 insertions(+), 1 deletions(-)

diff --git a/src/mathed/InsetMathNest.cpp b/src/mathed/InsetMathNest.cpp
index 896ca66..66e900a 100644
--- a/src/mathed/InsetMathNest.cpp
+++ b/src/mathed/InsetMathNest.cpp
@@ -373,9 +373,10 @@ void InsetMathNest::latex(otexstream & os, OutputParams 
const & runparams) const
        Changer dummy = wi.changeRowEntry(TexRow::textEntry(runparams.lastid,
                                                            runparams.lastpos));
        write(wi);
        // Reset parbreak status after a math inset.
        os.lastChar(0);
        os.canBreakLine(wi.canBreakLine());
+       os.terminateCommand(false);
 }
 
 
@@ -373,9 +373,10 @@ void InsetMathNest::latex(otexstream & os, OutputParams 
                                                            runparams.lastpos));
        write(wi);
-       // Reset parbreak status after a math inset.
+       // Reset parbreak and command termination status after a math inset.
        os.lastChar(0);
        os.canBreakLine(wi.canBreakLine());

Reply via email to